Class: Spacy::Span

Inherits:
Object
  • Object
show all
Includes:
Enumerable
Defined in:
lib/ruby-spacy.rb

Overview

See also spaCy Python API document for Span.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(doc, py_span: nil, start_index: nil, end_index: nil, options: {}) ⇒ Span

It is recommended to use Doc#span method to create a span. If you need to create one using #initialize, there are two method signatures: Span.new(doc, py_span: Object) or Span.new(doc, start_index: Integer, end_index: Integer, options: Hash).

Parameters:

  • doc (Doc)

    the document to which this span belongs to

  • start_index (Integer) (defaults to: nil)

    the index of the item starting the span inside a doc

  • end_index (Integer) (defaults to: nil)

    the index of the item ending the span inside a doc

  • options (Hash) (defaults to: {})

    options (:label, :kb_id, :vector)



926
927
928
929
930
# File 'lib/ruby-spacy.rb', line 926

def initialize(doc, py_span: nil, start_index: nil, end_index: nil, options: {})
  @doc = doc
  @py_span = py_span || PySpan.call(@doc.py_doc, start_index, end_index + 1, options)
  @text = @py_span.text
end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method

#method_missing(name, *args) ⇒ Object

Methods defined in Python but not wrapped in ruby-spacy can be called by this dynamic method handling mechanism.



1043
1044
1045
# File 'lib/ruby-spacy.rb', line 1043

def method_missing(name, *args)
  Spacy.safe_py_send(@py_span, name, args)
end

Instance Attribute Details

#docDoc (readonly)

Returns the document to which the span belongs.

Returns:

  • (Doc)

    the document to which the span belongs



908
909
910
# File 'lib/ruby-spacy.rb', line 908

def doc
  @doc
end

#py_spanObject (readonly)

Returns a Python Span instance accessible via PyCall.

Returns:

  • (Object)

    a Python Span instance accessible via PyCall



905
906
907
# File 'lib/ruby-spacy.rb', line 905

def py_span
  @py_span
end

#textString (readonly)

Returns a text string of the span.

Returns:

  • (String)

    a text string of the span



911
912
913
# File 'lib/ruby-spacy.rb', line 911

def text
  @text
end

Instance Method Details

#[](range) ⇒ Object

Returns a span if a range object is given or a token if an integer representing the position of the doc is given.

Parameters:

  • range (Range)

    an ordinary Ruby's range object such as 0..3, 1...4, or 3 .. -1



984
985
986
987
988
989
990
991
# File 'lib/ruby-spacy.rb', line 984

def [](range)
  if range.is_a?(Range)
    py_span = @py_span[range]
    Span.new(@doc, start_index: py_span.start, end_index: py_span.end - 1)
  else
    Token.new(@py_span[range])
  end
end

#as_docDoc

Creates a document instance from the span

Returns:



1002
1003
1004
# File 'lib/ruby-spacy.rb', line 1002

def as_doc
  Doc.new(@doc.py_nlp, text: text)
end

#conjunctsArray<Token>

Returns tokens conjugated to the root of the span.

Returns:

  • (Array<Token>)

    an array of tokens



1008
1009
1010
# File 'lib/ruby-spacy.rb', line 1008

def conjuncts
  PyCall::List.call(@py_span.conjuncts).map { |py_conjunct| Token.new(py_conjunct) }
end

#eachObject

Iterates over the elements in the span yielding a token instance each time.



939
940
941
942
943
# File 'lib/ruby-spacy.rb', line 939

def each
  PyCall::List.call(@py_span).each do |py_token|
    yield Token.new(py_token)
  end
end

#entsArray<Span>

Returns an array of spans that represents named entities.

Returns:



969
970
971
972
973
# File 'lib/ruby-spacy.rb', line 969

def ents
  PyCall::List.call(@py_span.ents).map do |py_span|
    Span.new(@doc, py_span: py_span)
  end
end

#instance_variables_to_inspectObject



1051
1052
1053
# File 'lib/ruby-spacy.rb', line 1051

def instance_variables_to_inspect
  [:@text]
end

#labelString

Returns the label

Returns:

  • (String)


1032
1033
1034
# File 'lib/ruby-spacy.rb', line 1032

def label
  @py_span.label_
end

#leftsArray<Token>

Returns tokens that are to the left of the span, whose heads are within the span.

Returns:

  • (Array<Token>)

    an array of tokens



1014
1015
1016
# File 'lib/ruby-spacy.rb', line 1014

def lefts
  PyCall::List.call(@py_span.lefts).map { |py_left| Token.new(py_left) }
end

#noun_chunksArray<Span>

Returns an array of spans of noun chunks.

Returns:



947
948
949
950
951
# File 'lib/ruby-spacy.rb', line 947

def noun_chunks
  PyCall::List.call(@py_span.noun_chunks).map do |py_span|
    Span.new(@doc, py_span: py_span)
  end
end

#respond_to_missing?(sym, include_private = false) ⇒ Boolean

Returns:

  • (Boolean)


1047
1048
1049
# File 'lib/ruby-spacy.rb', line 1047

def respond_to_missing?(sym, include_private = false)
  Spacy.py_hasattr?(@py_span, sym) || super
end

#rightsArray<Token>

Returns Tokens that are to the right of the span, whose heads are within the span.

Returns:

  • (Array<Token>)

    an array of Tokens



1020
1021
1022
# File 'lib/ruby-spacy.rb', line 1020

def rights
  PyCall::List.call(@py_span.rights).map { |py_right| Token.new(py_right) }
end

#rootToken

Returns the head token

Returns:



955
956
957
# File 'lib/ruby-spacy.rb', line 955

def root
  Token.new(@py_span.root)
end

#sentSpan

Returns a span that represents the sentence that the given span is part of.

Returns:



977
978
979
980
# File 'lib/ruby-spacy.rb', line 977

def sent
  py_span = @py_span.sent
  Span.new(@doc, py_span: py_span)
end

#sentsArray<Span>

Returns an array of spans that represents sentences.

Returns:



961
962
963
964
965
# File 'lib/ruby-spacy.rb', line 961

def sents
  PyCall::List.call(@py_span.sents).map do |py_span|
    Span.new(@doc, py_span: py_span)
  end
end

#similarity(other) ⇒ Float

Returns a semantic similarity estimate.

Parameters:

  • other (Span)

    the other span to which a similarity estimation is conducted

Returns:

  • (Float)


996
997
998
# File 'lib/ruby-spacy.rb', line 996

def similarity(other)
  py_span.similarity(other.py_span)
end

#subtreeArray<Token>

Returns Tokens that are within the span and tokens that descend from them.

Returns:

  • (Array<Token>)

    an array of tokens



1026
1027
1028
# File 'lib/ruby-spacy.rb', line 1026

def subtree
  PyCall::List.call(@py_span.subtree).map { |py_subtree| Token.new(py_subtree) }
end

#to_sString

String representation of the span.

Returns:

  • (String)


1038
1039
1040
# File 'lib/ruby-spacy.rb', line 1038

def to_s
  @text
end

#tokensArray<Token>

Returns an array of tokens contained in the span.

Returns:



934
935
936
# File 'lib/ruby-spacy.rb', line 934

def tokens
  PyCall::List.call(@py_span).map { |py_token| Token.new(py_token) }
end